@@ -118,13 +118,13 @@ namespace
         switch ( suit )
         {
         case KCardDeck::Clubs:
-            return "clubs";
+            return QStringLiteral("clubs");
         case KCardDeck::Diamonds:
-            return "diamonds";
+            return QStringLiteral("diamonds");
         case KCardDeck::Hearts:
-            return "hearts";
+            return QStringLiteral("hearts");
         case KCardDeck::Spades:
-            return "spades";
+            return QStringLiteral("spades");
         default:
             return QString();
         }
@@ -135,31 +135,31 @@ namespace
         switch ( rank )
         {
         case KCardDeck::Ace:
-            return "ace";
+            return QStringLiteral("ace");
         case KCardDeck::Two:
-            return "two";
+            return QStringLiteral("two");
         case KCardDeck::Three:
-            return "three";
+            return QStringLiteral("three");
         case KCardDeck::Four:
-            return "four";
+            return QStringLiteral("four");
         case KCardDeck::Five:
-            return "five";
+            return QStringLiteral("five");
         case KCardDeck::Six:
-            return "six";
+            return QStringLiteral("six");
         case KCardDeck::Seven:
-            return "seven";
+            return QStringLiteral("seven");
         case KCardDeck::Eight:
-            return "eight";
+            return QStringLiteral("eight");
         case KCardDeck::Nine:
-            return "nine";
+            return QStringLiteral("nine");
         case KCardDeck::Ten:
-            return "ten";
+            return QStringLiteral("ten");
         case KCardDeck::Jack:
-            return "jack";
+            return QStringLiteral("jack");
         case KCardDeck::Queen:
-            return "queen";
+            return QStringLiteral("queen");
         case KCardDeck::King:
-            return "king";
+            return QStringLiteral("king");
         default:
             return QString();
         }
@@ -214,29 +214,29 @@ void DealerScene::saveLegacyFile( QIODevice * io )
     xml.setAutoFormattingIndent( -1 );
     xml.writeStartDocument();
 
-    xml.writeDTD( "<!DOCTYPE kpat>" );
+    xml.writeDTD( QStringLiteral("<!DOCTYPE kpat>") );
 
-    xml.writeStartElement( "dealer" );
-    xml.writeAttribute( "id", QString::number( gameId() ) );
-    xml.writeAttribute( "options", getGameOptions() );
-    xml.writeAttribute( "number", QString::number( gameNumber() ) );
-    xml.writeAttribute( "moves", QString::number( moveCount() ) );
-    xml.writeAttribute( "started", QString::number( m_dealStarted ) );
-    xml.writeAttribute( "data", getGameState() );
+    xml.writeStartElement( QStringLiteral("dealer") );
+    xml.writeAttribute( QStringLiteral("id"), QString::number( gameId() ) );
+    xml.writeAttribute( QStringLiteral("options"), getGameOptions() );
+    xml.writeAttribute( QStringLiteral("number"), QString::number( gameNumber() ) );
+    xml.writeAttribute( QStringLiteral("moves"), QString::number( moveCount() ) );
+    xml.writeAttribute( QStringLiteral("started"), QString::number( m_dealStarted ) );
+    xml.writeAttribute( QStringLiteral("data"), getGameState() );
 
     foreach( const PatPile * p, patPiles() )
     {
-        xml.writeStartElement( "pile" );
-        xml.writeAttribute( "index", QString::number( p->index() ) );
-        xml.writeAttribute( "z", QString::number( p->zValue() ) );
+        xml.writeStartElement( QStringLiteral("pile") );
+        xml.writeAttribute( QStringLiteral("index"), QString::number( p->index() ) );
+        xml.writeAttribute( QStringLiteral("z"), QString::number( p->zValue() ) );
 
         foreach( const KCard * c, p->cards() )
         {
-            xml.writeStartElement( "card" );
-            xml.writeAttribute( "suit", QString::number( c->suit() ) );
-            xml.writeAttribute( "value", QString::number( c->rank() ) );
-            xml.writeAttribute( "faceup", QString::number( c->isFaceUp() ) );
-            xml.writeAttribute( "z", QString::number( c->zValue() ) );
+            xml.writeStartElement( QStringLiteral("card") );
+            xml.writeAttribute( QStringLiteral("suit"), QString::number( c->suit() ) );
+            xml.writeAttribute( QStringLiteral("value"), QString::number( c->rank() ) );
+            xml.writeAttribute( QStringLiteral("faceup"), QString::number( c->isFaceUp() ) );
+            xml.writeAttribute( QStringLiteral("z"), QString::number( c->zValue() ) );
             xml.writeEndElement();
         }
         xml.writeEndElement();
@@ -262,13 +262,13 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
     // this never caused crashes. Fortunately, in Spider we can count the
     // number of suits ourselves. For Klondike, there is no way to recover
     // that information.
-    QString options = xml.attributes().value( "options" ).toString();
+    QString options = xml.attributes().value( QStringLiteral("options") ).toString();
     if ( gameId() == 17 && options.isEmpty() )
     {
         QSet<int> suits;
         while ( !xml.atEnd() )
             if ( xml.readNextStartElement() && xml.name() == "card" )
-                suits << readIntAttribute( xml, "suit" );
+                suits << readIntAttribute( xml, QStringLiteral("suit") );
         options = QString::number( suits.size() );
 
         // "Rewind" back to the <dealer> tag. Yes, this is ugly.
@@ -279,10 +279,10 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
     }
     setGameOptions( options );
 
-    m_dealNumber = readIntAttribute( xml, "number" );
-    m_loadedMoveCount = readIntAttribute( xml, "moves" );
-    m_dealStarted = readIntAttribute( xml, "started" );
-    QString gameStateData = xml.attributes().value( "data" ).toString();
+    m_dealNumber = readIntAttribute( xml, QStringLiteral("number") );
+    m_loadedMoveCount = readIntAttribute( xml, QStringLiteral("moves") );
+    m_dealStarted = readIntAttribute( xml, QStringLiteral("started") );
+    QString gameStateData = xml.attributes().value( QStringLiteral("data") ).toString();
 
     QMultiHash<quint32,KCard*> cards;
     foreach ( KCard * c, deck()->cards() )
@@ -302,11 +302,11 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
         }
 
         bool ok;
-        int index = readIntAttribute( xml, "index", &ok );
+        int index = readIntAttribute( xml, QStringLiteral("index"), &ok );
         QHash<int,PatPile*>::const_iterator it = piles.constFind( index );
         if ( !ok || it == piles.constEnd() )
         {
-            qWarning() << "Unrecognized pile index:" << xml.attributes().value( "index" );
+            qWarning() << "Unrecognized pile index:" << xml.attributes().value( QStringLiteral("index") );
             return false;
         }
 
@@ -323,18 +323,18 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
             }
             
             bool suitOk, rankOk, faceUpOk;
-            int suit = readIntAttribute( xml, "suit", &suitOk );
-            int rank = readIntAttribute( xml, "value", &rankOk );
-            bool faceUp = readIntAttribute( xml, "faceup", &faceUpOk );
+            int suit = readIntAttribute( xml, QStringLiteral("suit"), &suitOk );
+            int rank = readIntAttribute( xml, QStringLiteral("value"), &rankOk );
+            bool faceUp = readIntAttribute( xml, QStringLiteral("faceup"), &faceUpOk );
             
             quint32 id = KCardDeck::getId( KCardDeck::Suit( suit ), KCardDeck::Rank( rank ), 0 );
             KCard * card = cards.take( id );
 
             if ( !suitOk || !rankOk || !faceUpOk || !card )
             {
-                qWarning() << "Unrecognized card: suit=" << xml.attributes().value("suit")
-                           << " value=" << xml.attributes().value("value")
-                           << " faceup=" << xml.attributes().value("faceup");
+                qWarning() << "Unrecognized card: suit=" << xml.attributes().value(QStringLiteral("suit"))
+                           << " value=" << xml.attributes().value(QStringLiteral("value"))
+                           << " faceup=" << xml.attributes().value(QStringLiteral("faceup"));
                 return false;
             }
 
@@ -364,11 +364,11 @@ void DealerScene::saveFile( QIODevice * io )
     xml.setAutoFormattingIndent( -1 );
     xml.writeStartDocument();
 
-    xml.writeStartElement( "kpat-game" );
-    xml.writeAttribute( "game-type", m_di->baseIdString() );
+    xml.writeStartElement( QStringLiteral("kpat-game") );
+    xml.writeAttribute( QStringLiteral("game-type"), m_di->baseIdString() );
     if ( !getGameOptions().isEmpty() )
-        xml.writeAttribute( "game-type-options", getGameOptions() );
-    xml.writeAttribute( "deal-number", QString::number( gameNumber() ) );
+        xml.writeAttribute( QStringLiteral("game-type-options"), getGameOptions() );
+    xml.writeAttribute( QStringLiteral("deal-number"), QString::number( gameNumber() ) );
 
     QList<GameState*> allStates;
     for ( int i = 0; i < m_undoStack.size(); ++i )
@@ -382,32 +382,32 @@ void DealerScene::saveFile( QIODevice * io )
     for ( int i = 0; i < allStates.size(); ++i )
     {
         const GameState * state = allStates.at( i );
-        xml.writeStartElement( "state" );
+        xml.writeStartElement( QStringLiteral("state") );
         if ( state->stateData != lastGameSpecificState )
         {
-            xml.writeAttribute( "game-specific-state", state->stateData );
+            xml.writeAttribute( QStringLiteral("game-specific-state"), state->stateData );
             lastGameSpecificState = state->stateData;
         }
         if ( i == m_undoStack.size() )
-            xml.writeAttribute( "current", "true" );
+            xml.writeAttribute( QStringLiteral("current"), QStringLiteral("true") );
 
         foreach ( const CardStateChange & change, state->changes )
         {
-            xml.writeStartElement( "move" );
-            xml.writeAttribute( "pile", change.newState.pile->objectName() );
-            xml.writeAttribute( "position", QString::number( change.newState.index ) );
+            xml.writeStartElement( QStringLiteral("move") );
+            xml.writeAttribute( QStringLiteral("pile"), change.newState.pile->objectName() );
+            xml.writeAttribute( QStringLiteral("position"), QString::number( change.newState.index ) );
 
             bool faceChanged = !change.oldState.pile
                                || change.oldState.faceUp != change.newState.faceUp;
 
             foreach ( const KCard * card, change.cards )
             {
-                xml.writeStartElement( "card" );
-                xml.writeAttribute( "id", QString("%1").arg( card->id(), 7, 10, QChar('0') ) );
-                xml.writeAttribute( "suit", suitToString( card->suit() ) );
-                xml.writeAttribute( "rank", rankToString( card->rank() ) );
+                xml.writeStartElement( QStringLiteral("card") );
+                xml.writeAttribute( QStringLiteral("id"), QStringLiteral("%1").arg( card->id(), 7, 10, QChar('0') ) );
+                xml.writeAttribute( QStringLiteral("suit"), suitToString( card->suit() ) );
+                xml.writeAttribute( QStringLiteral("rank"), rankToString( card->rank() ) );
                 if ( faceChanged )
-                    xml.writeAttribute( "turn", change.newState.faceUp ? "face-up" : "face-down" );
+                    xml.writeAttribute( QStringLiteral("turn"), change.newState.faceUp ? "face-up" : "face-down" );
                 xml.writeEndElement();
             }
 
@@ -440,8 +440,8 @@ bool DealerScene::loadFile( QIODevice * io )
         return false;
     }
 
-    m_dealNumber = readIntAttribute( xml, "deal-number" );
-    setGameOptions( xml.attributes().value( "game-type-options" ).toString() );
+    m_dealNumber = readIntAttribute( xml, QStringLiteral("deal-number") );
+    setGameOptions( xml.attributes().value( QStringLiteral("game-type-options") ).toString() );
 
     QMultiHash<quint32,KCard*> cardHash;
     foreach ( KCard * c, deck()->cards() )
@@ -461,12 +461,12 @@ bool DealerScene::loadFile( QIODevice * io )
             return false;
         }
 
-        if ( xml.attributes().hasAttribute( "game-specific-state" ) )
-            setGameState( xml.attributes().value( "game-specific-state" ).toString() );
+        if ( xml.attributes().hasAttribute( QStringLiteral("game-specific-state") ) )
+            setGameState( xml.attributes().value( QStringLiteral("game-specific-state") ).toString() );
 
         if ( undosToDo > -1 )
             ++undosToDo;
-        else if ( xml.attributes().value( "current" ) == "true" )
+        else if ( xml.attributes().value( QStringLiteral("current") ) == "true" )
             undosToDo = 0;
         
         while( xml.readNextStartElement() )
@@ -477,11 +477,11 @@ bool DealerScene::loadFile( QIODevice * io )
                 return false;
             }
 
-            QString pileName = xml.attributes().value( "pile" ).toString();
+            QString pileName = xml.attributes().value( QStringLiteral("pile") ).toString();
             KCardPile * pile = pileHash.value( pileName );
 
             bool indexOk;
-            int index = readIntAttribute( xml, "position", &indexOk );
+            int index = readIntAttribute( xml, QStringLiteral("position"), &indexOk );
 
             if ( !pile || !indexOk )
             {
@@ -497,16 +497,16 @@ bool DealerScene::loadFile( QIODevice * io )
                     return false;
                 }
 
-                KCard * card = cardHash.value( readIntAttribute( xml, "id" ) );
+                KCard * card = cardHash.value( readIntAttribute( xml, QStringLiteral("id") ) );
                 if ( !card )
                 {
                     qWarning() << "Unrecognized card.";
                     return false;
                 }
 
-                if ( xml.attributes().value("turn") == "face-up" )
+                if ( xml.attributes().value(QStringLiteral("turn")) == "face-up" )
                     card->setFaceUp( true );
-                else if ( xml.attributes().value("turn") == "face-down" )
+                else if ( xml.attributes().value(QStringLiteral("turn")) == "face-down" )
                     card->setFaceUp( false );
                 
                 pile->insert( index, card );
@@ -954,12 +954,12 @@ void DealerScene::won()
         c->animate( pos2, c->zValue(), 0, true, false, dist / speed );
     }
 
-    connect(deck(), SIGNAL(cardAnimationDone()), this, SLOT(showWonMessage()));
+    connect(deck(), &KAbstractCardDeck::cardAnimationDone, this, &DealerScene::showWonMessage);
 }
 
 void DealerScene::showWonMessage()
 {
-    disconnect(deck(), SIGNAL(cardAnimationDone()), this, SLOT(showWonMessage()));
+    disconnect(deck(), &KAbstractCardDeck::cardAnimationDone, this, &DealerScene::showWonMessage);
 
     // It shouldn't be necessary to stop the demo yet again here, but we
     // get crashes if we don't. Will have to look into this further.
@@ -976,7 +976,7 @@ void DealerScene::showWonMessage()
 
 void DealerScene::updateWonItem()
 {
-    const qreal aspectRatio = Renderer::self()->aspectRatioOfElement("message_frame");
+    const qreal aspectRatio = Renderer::self()->aspectRatioOfElement(QStringLiteral("message_frame"));
     int boxWidth;
     int boxHeight;
     if ( width() < aspectRatio * height() )
@@ -1753,12 +1753,12 @@ void DealerScene::recordGameStatistics()
     {
         int id = oldId();
 
-        QString totalPlayedKey = QString("total%1").arg( id );
-        QString wonKey = QString("won%1").arg( id );
-        QString winStreakKey = QString("winstreak%1").arg( id );
-        QString maxWinStreakKey = QString("maxwinstreak%1").arg( id );
-        QString loseStreakKey = QString("loosestreak%1").arg( id );
-        QString maxLoseStreakKey = QString("maxloosestreak%1").arg( id );
+        QString totalPlayedKey = QStringLiteral("total%1").arg( id );
+        QString wonKey = QStringLiteral("won%1").arg( id );
+        QString winStreakKey = QStringLiteral("winstreak%1").arg( id );
+        QString maxWinStreakKey = QStringLiteral("maxwinstreak%1").arg( id );
+        QString loseStreakKey = QStringLiteral("loosestreak%1").arg( id );
+        QString maxLoseStreakKey = QStringLiteral("maxloosestreak%1").arg( id );
 
         KConfigGroup config(KSharedConfig::openConfig(), scores_group);
 
@@ -1960,7 +1960,7 @@ bool DealerScene::allowedToStartNewGame()
                      i18n("Abandon Current Game?"),
                      KGuiItem(i18n("Abandon Current Game")),
                      KStandardGuiItem::cancel(),
-                     "careaboutstats"
+                     QStringLiteral("careaboutstats")
                     ) == KMessageBox::Continue;
 }
 
