@@ -19,7 +19,7 @@
 
 #include "../simon.h"
 
-#include <KDebug>
+#include <QDebug>
 
 
 #define PRINT 0
@@ -29,7 +29,7 @@
 void SimonSolver::make_move(MOVE *m)
 {
 #if PRINT
-    kDebug() << "\n\nmake_move\n";
+    //qDebug() << "\n\nmake_move\n";
     if ( m->totype == O_Type )
         fprintf( stderr, "move %d from %d out (at %d) Prio: %d\n\n", m->card_index, m->from, m->turn_index, m->pri );
     else
@@ -83,7 +83,7 @@ void SimonSolver::make_move(MOVE *m)
 void SimonSolver::undo_move(MOVE *m)
 {
 #if PRINT
-    kDebug() << "\n\nundo_move\n";
+    //qDebug() << "\n\nundo_move\n";
     if ( m->totype == O_Type )
         fprintf( stderr, "move %d from %d out (at %d)\n\n", m->card_index, m->from, m->turn_index );
     else
