@@ -57,7 +57,7 @@ void Simon::initialize()
 
     for ( int i = 0; i < 4; ++i )
     {
-        target[i] = new PatPile( this, i + 1, QString( "target%1" ).arg( i ) );
+        target[i] = new PatPile( this, i + 1, QStringLiteral( "target%1" ).arg( i ) );
         target[i]->setPileRole(PatPile::Foundation);
         target[i]->setLayoutPos((i+3)*dist_x, 0);
         target[i]->setSpread(0, 0);
@@ -67,7 +67,7 @@ void Simon::initialize()
 
     for ( int i = 0; i < 10; ++i )
     {
-        store[i] = new PatPile( this, 5 + i, QString( "store%1" ).arg( i ) );
+        store[i] = new PatPile( this, 5 + i, QStringLiteral( "store%1" ).arg( i ) );
         store[i]->setPileRole(PatPile::Tableau);
         store[i]->setLayoutPos(dist_x*i, 1.2);
         store[i]->setBottomPadding( 2.5 );
